@@ -5,6 +5,8 @@ from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.loggers.model_logger import BaseGalileoModelLogger
+from dataquality.schemas.ner import TaggingSchema
+from dataquality.schemas.split import Split
 from dataquality.schemas.task_type import TaskType
 
 
@@ -14,7 +16,9 @@ def log_input_data(**kwargs: Any) -> None:
     The expected arguments come from the task_type's data
     logger: See dataquality.get_model_logger().doc() for details
     """
-    assert config.task_type, "You must call dataquality.init before logging data"
+    assert all(
+        [config.task_type, config.current_project_id, config.current_run_id]
+    ), "You must call dataquality.init before logging data"
     data_logger = get_data_logger()(**kwargs)
     data_logger.log()
 
@@ -33,7 +37,9 @@ def log_model_outputs(**kwargs: Any) -> None:
     The expected arguments come from the task_type's model
     logger: See dataquality.get_model_logger().doc() for details
     """
-    assert config.task_type, "You must call dataquality.init before logging data"
+    assert all(
+        [config.task_type, config.current_project_id, config.current_run_id]
+    ), "You must call dataquality.init before logging data"
     model_logger = get_model_logger()(**kwargs)
     model_logger.log()
 
@@ -68,6 +74,14 @@ def set_tasks_for_run(tasks: List[str]) -> None:
     get_data_logger().logger_config.tasks = tasks
 
 
+def set_tagging_schema(tagging_schema: TaggingSchema) -> None:
+    """Sets the tagging schema for NER models
+
+    Only valid for text_ner task_types. Others will throw an exception
+    """
+    get_data_logger().set_tagging_schema(tagging_schema)
+
+
 def get_model_logger(task_type: TaskType = None) -> Type[BaseGalileoModelLogger]:
     task_type = _get_task_type(task_type)
     return BaseGalileoModelLogger.get_logger(task_type)
@@ -95,3 +109,19 @@ def docs() -> None:
     """
     get_data_logger().doc()
     get_model_logger().doc()
+
+
+def set_epoch(epoch: int) -> None:
+    """Set the current epoch.
+
+    When set, logging model outputs will use this if not logged explicitly
+    """
+    get_data_logger().logger_config.cur_epoch = epoch
+
+
+def set_split(split: Split) -> None:
+    """Set the current split.
+
+    When set, logging data inputs/model outputs will use this if not logged explicitly
+    """
+    get_data_logger().logger_config.cur_split = split
