@@ -1,7 +1,10 @@
 from abc import abstractmethod
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union
 from uuid import uuid4
 
+import numpy as np
+from scipy.special import softmax
+
 from dataquality import config
 from dataquality.exceptions import GalileoException
 from dataquality.loggers.base_logger import BaseGalileoLogger
@@ -16,10 +19,6 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
         super().__init__()
         self.epoch: Optional[int] = None
 
-    @abstractmethod
-    def validate(self) -> None:
-        ...
-
     def _log(self) -> None:
         """Threaded logger target"""
         try:
@@ -53,6 +52,18 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
         object_name = f"{str(uuid4()).replace('-', '')[:12]}.hdf5"
         _save_hdf5_file(path, object_name, data)
 
+    @abstractmethod
+    def validate(self) -> None:
+        super().validate()
+        if self.epoch is None:
+            if self.logger_config.cur_epoch is not None:
+                self.epoch = self.logger_config.cur_epoch
+            else:
+                raise GalileoException(
+                    "You must either log an epoch or set it before logging. Use "
+                    "`dataquality.set_epoch` to set the epoch"
+                )
+
     @classmethod
     def upload(cls) -> None:
         """The upload function is implemented in the sister DataConfig class"""
@@ -61,8 +72,8 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
     @staticmethod
     def get_model_logger_attr(cls: object) -> str:
         """
-        Returns the attribute that corresponds to the GalileoModelConfig class.
-        This assumes only 1 GalileoModelConfig object exists in the class
+        Returns the attribute that corresponds to the GalileoModelLogger class.
+        This assumes only 1 GalileoModelLogger object exists in the class
 
         :param cls: The class
         :return: The attribute name
@@ -71,8 +82,16 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
             member_class = getattr(cls, attr)
             if isinstance(member_class, BaseGalileoModelLogger):
                 return attr
-        raise AttributeError("No GalileoModelConfig attribute found!")
+        raise AttributeError("No model logger attribute found!")
 
     @abstractmethod
     def _get_data_dict(self) -> Dict:
         """Constructs a dictionary of arrays from logged model output data"""
+
+    def convert_logits_to_probs(
+        self, sample_logits: Union[List[np.ndarray], np.ndarray]
+    ) -> np.ndarray:
+        """Converts logits to probs via softmax"""
+        # axis ensures that in a matrix of probs with dims num_samples x num_classes
+        # we take the softmax for each sample
+        return softmax(np.array(sample_logits), axis=-1)
