@@ -29,7 +29,7 @@ class GalileoModelLoggerAttributes(str, Enum):
     split = "split"  # type: ignore
     epoch = "epoch"
     dep_scores = "dep_scores"
-    user_helper_data = "user_helper_data"
+    log_helper_data = "log_helper_data"
 
     @staticmethod
     def get_valid() -> List[str]:
@@ -117,7 +117,7 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         self.pred_dep: List[List[float]] = []
 
         # Used for helper data, does not get logged
-        self.user_helper_data: Dict[str, Any] = {}
+        self.log_helper_data: Dict[str, Any] = {}
 
     @staticmethod
     def get_valid_attributes() -> List[str]:
@@ -162,10 +162,6 @@ class TextNERModelLogger(BaseGalileoModelLogger):
                 logged_sample_ids.append(sample_id)
 
         self.ids = logged_sample_ids
-        # Get the embedding shape. Filter out nulls
-        if not self.logger_config.num_emb:
-            emb = next(filter(lambda emb: not np.isnan(emb[0]).all(), self.gold_emb))[0]
-            self.logger_config.num_emb = emb.shape[0]
 
     def _process_sample(
         self, sample_id: int, sample_emb: np.ndarray, sample_prob: np.ndarray
