@@ -1,6 +1,5 @@
 import os
 import threading
-from collections import Counter
 from typing import Dict, List
 
 import h5py
@@ -10,6 +9,7 @@ from vaex.arrow.convert import arrow_string_array_from_buffers as convert_bytes
 from vaex.dataframe import DataFrame
 
 from dataquality.exceptions import GalileoException
+from dataquality.loggers.base_logger import BaseLoggerAttributes
 from dataquality.utils import tqdm
 from dataquality.utils.hdf5_store import HDF5_STORE, HDF5Store
 
@@ -28,7 +28,11 @@ def _save_hdf5_file(location: str, file_name: str, data: Dict) -> None:
         for col in data:
             group = f.create_group(f"/table/columns/{col}")
             col_data = np.array(data[col])
-            if not np.issubdtype(col_data.dtype, np.number):  # String columns
+            # String columns
+            ctype = col_data.dtype
+            if not np.issubdtype(ctype, np.number) and not np.issubdtype(
+                ctype, np.bool_
+            ):
                 dtype = h5py.string_dtype()
                 col_data = col_data.astype(dtype)
             else:
@@ -42,11 +46,13 @@ def _save_hdf5_file(location: str, file_name: str, data: Dict) -> None:
 def _join_in_out_frames(in_df: DataFrame, out_df: DataFrame) -> DataFrame:
     """Helper function to join our input and output frames"""
     in_frame = in_df.copy()
+    # There is an odd vaex bug where sometimes we lose the continuity of this dataframe
+    # it's hard to reproduce, only shows up on linux, and hasn't been pinpointed yet
+    # but materializing the join-key column fixes the issue
+    in_frame["id"] = in_frame["id"].values
     out_frame = out_df.copy()
-    in_frame["split_id"] = in_frame["split"] + in_frame["id"].astype("string")
-    out_frame["split_id"] = out_frame["split"] + out_frame["id"].astype("string")
     in_out = out_frame.join(
-        in_frame, on="split_id", how="inner", lsuffix="_L", rsuffix="_R"
+        in_frame, on="id", how="inner", lsuffix="_L", rsuffix="_R"
     ).copy()
     if len(in_out) != len(out_frame):
         num_missing = len(out_frame) - len(in_out)
@@ -72,15 +78,31 @@ def _validate_unique_ids(df: DataFrame) -> None:
     """
     if df["id"].nunique() != len(df):
         epoch, split = df[["epoch", "split"]][0]
-        all_ids: List[int] = df["id"].tolist()
-        dup_ids = [i for i, count in Counter(all_ids).items() if count > 1]
+        dups = get_dup_ids(df)
         raise GalileoException(
             "It seems as though you do not have unique ids in this "
-            f"split/epoch. Did you provide your own IDs?\n"
-            f"split:{split}, epoch:{epoch}, dup ids:{dup_ids}"
+            f"split/epoch. Did you provide your own IDs? Or did you log for the same "
+            f"Split multiple times? Check where you are logging {split} data\n"
+            f"split:{split}, epoch:{epoch}, dup ids and counts:{dups}"
         )
 
 
+def valid_ids(df: DataFrame) -> bool:
+    """Returns whether or not a dataframe has unique IDs"""
+    try:
+        _validate_unique_ids(df)
+        return True
+    except GalileoException:
+        return False
+
+
+def get_dup_ids(df: DataFrame) -> List:
+    """Gets the list of duplicate IDs in a dataframe, if any"""
+    df_copy = df.copy()
+    dup_df = df_copy.groupby(by="id", agg="count")
+    return dup_df[dup_df["count"] > 1].to_records()
+
+
 def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
     """Concatenates all hdf5 in a directory using an HDF5 store
 
@@ -104,6 +126,8 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
         cols = ["id"]
         cols += [c for c in df.get_column_names() if c.startswith("prob")]
         cols += [c for c in df.get_column_names() if c.startswith("gold")]
+        cols += [c for c in df.get_column_names() if c.endswith("_gold")]
+        cols += [c for c in df.get_column_names() if c.endswith("_pred")]
     else:
         cols = df.get_column_names()
     for col in cols:
@@ -114,7 +138,7 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
         else:
             shape = ()
         dtype = df[col].dtype.numpy
-        if not np.issubdtype(dtype, np.number):
+        if not np.issubdtype(dtype, np.number) and not np.issubdtype(dtype, np.bool_):
             dtype = h5py.string_dtype(encoding="utf-8")
             str_cols.append(col)
         stores[col] = HDF5Store(f"{location}/{HDF5_STORE}", group, shape, dtype=dtype)
@@ -136,6 +160,18 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
                     d = convert_bytes(data, indcs, None).to_numpy(zero_copy_only=False)
                 else:
                     d = col_data["data"][:]
+                if key in str_cols:
+                    d = d.astype(h5py.string_dtype(encoding="utf-8"))
                 stores[key].append(d)
         os.remove(fname)
     return str_cols
+
+
+def drop_empty_columns(df: DataFrame) -> DataFrame:
+    """Drops any columns that have no values"""
+    cols = df.get_column_names()
+    # Don't need to check the default columns, they've already been validated
+    cols = [c for c in cols if c not in list(BaseLoggerAttributes)]
+    col_counts = df.count(cols)
+    empty_cols = [col for col, col_count in zip(cols, col_counts) if col_count == 0]
+    return df.drop(*empty_cols) if empty_cols else df
