@@ -14,7 +14,7 @@ from tests.conftest import LOCATION, SPLITS, SUBDIRS, TEST_PATH
 
 NUM_RECORDS = 50
 NUM_LOGS = 30
-MULTI_LABEL_NUM_TASKS = 10
+MULTI_LABEL_NUM_TASKS = 4
 
 
 def validate_uploaded_data(
@@ -31,9 +31,15 @@ def validate_uploaded_data(
         # Output data
         split_output_data = {}
         for subdir in SUBDIRS:
-            file_path = f"{TEST_PATH}/{split}/{subdir}/{subdir}.hdf5"
-            # Ensure files were cleaned up
-            data = vaex.open(file_path)
+            # epoch = 0 for general testing
+            try:
+                file_path = f"{TEST_PATH}/{split}/0/{subdir}/{subdir}.hdf5"
+                data = vaex.open(file_path)
+            except FileNotFoundError:
+                # Handle autolog test
+                file_path = f"{TEST_PATH}/{split}/1/{subdir}/{subdir}.hdf5"
+                data = vaex.open(file_path)
+
             prob_cols = data.get_column_names(regex="prob*")
             for c in data.get_column_names():
                 if c in prob_cols + ["emb"]:
@@ -58,6 +64,10 @@ def validate_uploaded_data(
             == sorted(emb["id"].unique())
             == sorted(prob["id"].unique())
         )
+        # Since we log logits, the probs should all sum to 1
+        for col in prob.get_column_names(regex="prob*"):
+            probs = prob[col].values
+            assert np.allclose(1, np.sum(probs, axis=-1))
         if multi_label:
             for c in prob.get_column_names():
                 assert c == "id" or c.startswith("prob_") or c.startswith("gold_")
@@ -79,7 +89,7 @@ def validate_cleanup_data():
         assert not os.path.isdir(f"{LOCATION}/{split}")
 
 
-def _log_data(
+def _log_text_classification_data(
     num_records=NUM_RECORDS,
     num_logs=NUM_LOGS,
     unique_ids=True,
@@ -88,7 +98,7 @@ def _log_data(
     multi_label=False,
 ) -> None:
     """
-    Logs some mock data to disk
+    Logs mock data for text classification/multi-label to disk
     """
     meta = meta or {}
     # Log train/test data
@@ -116,9 +126,8 @@ def _log_data(
         else:
             labels = dataset["label"]
             dataquality.set_labels_for_run([str(i) for i in range(len(set(labels)))])
-        dataquality.log_input_data(
-            text=dataset["text"], labels=labels, split=split.value, meta=meta
-        )
+        dataquality.set_split(split)
+        dataquality.log_input_data(text=dataset["text"], labels=labels, meta=meta)
 
     num_labels_in_task = np.random.randint(low=1, high=10, size=MULTI_LABEL_NUM_TASKS)
     if multi_label:
@@ -128,14 +137,14 @@ def _log_data(
         for ln in tqdm(range(num_logs)):
             emb = [[random() for _ in range(num_emb)] for _ in range(num_records)]
             if multi_label:
-                probs = []
+                logits = []
                 for i in range(num_records):
-                    probs_per_task = []
+                    logits_per_task = []
                     for num_labels in num_labels_in_task:
-                        probs_per_task.append(np.random.rand(num_labels))
-                    probs.append(probs_per_task)
+                        logits_per_task.append(np.random.rand(num_labels))
+                    logits.append(logits_per_task)
             else:
-                probs = np.random.rand(num_records, len(set(labels)))
+                logits = np.random.rand(num_records, len(set(labels)))
             epoch = 0
 
             # Need unique ids
@@ -145,6 +154,6 @@ def _log_data(
             else:
                 ids = list(range(num_records))
 
-            dataquality.log_model_outputs(
-                emb=emb, probs=probs, split=split.value, epoch=epoch, ids=ids
-            )
+            dataquality.set_epoch(epoch)
+            dataquality.set_split(split)
+            dataquality.log_model_outputs(emb=emb, logits=logits, ids=ids)
